==> bee_hotel-2.13.x-dev.tar.gz: bee_hotel/src/Form/UnitsSearch.php <==
<?php

namespace Drupal\bee_hotel\Form;

use Drupal\Core\Link;
use Drupal\bee_hotel\Util\BeeHotelUnit;
use Drupal\commerce\Context;
use Drupal\commerce_price\Resolver\ChainPriceResolverInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\NodeInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Search form for available beehotel units.
 */
class UnitsSearch extends FormBase {

  /**
   * The chain price resolver.
   *
   * @var \Drupal\commerce_price\Resolver\ChainPriceResolverInterface
   */
  protected $chainPriceResolver;

  /**
   * Constructs a new UnitsSeach object.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   User account.
   * @param \Drupal\commerce_price\Resolver\ChainPriceResolverInterface $chain_price_resolver
   *   Chain price resolver.
   */
  public function __construct(AccountInterface $account, ChainPriceResolverInterface $chain_price_resolver) {
    $this->account = $account;
    $this->chainPriceResolver = $chain_price_resolver;
    $this->beehotelunit = new BeeHotelUnit($data = []);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load required services to construct this class.
      $container->get('current_user'),
      $container->get('commerce_price.chain_price_resolver'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'beehotel_units_search';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, NodeInterface $node = NULL) {

    $config = $this->config('beehotel.settings');

    if ($config->get("beehotel.off_value")) {
      \Drupal::messenger()->addWarning($config->get("beehotel.off_text"));
      return;
    }

    // Get current user data.
    $uid = $this->account->id();

    // Clean booking related data in session.
    $session = \Drupal::request()->getSession();
    $session->set('beehotel_data', []);

    $today = new \DateTime();

    $tomorrow = clone($today);
    $tomorrow->modify('+1 day');

    $one_hour_later = clone($today);
    $one_hour_later->modify('+1 hour');

    $form['numbers'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
    ];

    // Dates.
    $form['numbers']['dates'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Check in > Check out'),
      '#default_value' => date("j M Y", strtotime("+1 day")) . " - " . date("j M Y", strtotime("+3 day")),
      '#required' => TRUE,
      '#weight' => -1000,
    ];

    // People (occupants).
    $max_occupancy = $this->beehotelunit->maxOccupancy($node = NULL);
    $options = [];
    for ($o = 1; $o <= $max_occupancy; $o++) {
      $options[$o] = $o;
    }

    $form['numbers']['guests'] = [
      '#type' => 'select',
      '#title' => $this->t('Guests'),
      '#options' => $options,
      '#required' => TRUE,
    ];

    // Submit area.
    $form['actions'] = [
      '#type' => 'fieldset',
      '#collapsible' => FALSE,
      '#description' => "",
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => t('Search'),
    ];

    if ($form_state->getTriggeringElement()) {
      $items = $this->produceResult($form_state);
      $form['#suffix'] = t("Results") . "<div class='units'>" . render($items) . "</div>";
    }

    $form['#attached']['library'][] = 'bee_hotel/beehotel-litepicker';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $data['values'] = $form_state->getValues();
    $data = $this->beehotelunit->getAvailableUnits($data);
    // Basic date validation.
    if (empty($data['available_units'])) {
      $form_state->setErrorByName('checkout', $this->t('No availability, sorry...'));
      return;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRebuild(TRUE);
  }

  /**
   * Produce results.
   *
   * Produce results from submitted values.
   */
  private function produceResult($form_state) {
    $data = [];
    $data['values'] = $form_state->getValues();

    $data = $this->beehotelunit->getAvailableUnits($data);

    foreach ($data['available_units'] as $unit_id) {

      $beeHotelUnit = $this->beehotelunit->getUnitFromBid($unit_id);

      if (isset($beeHotelUnit)) {

        // Unit disabled.
        if ($beeHotelUnit['node']->get("status")->value != 1) {
          continue;
        }

        // Unit not accepting reservations.
        if ($beeHotelUnit['node']->get("field_accept_reservations")->value != 1) {
          continue;
        }

        $variation = $this->beehotelunit->GetCurrentVariation($beeHotelUnit, $data);

        if (isset($variation)) {

          $data['v_param'] = $data['norm']['dates_from_search_form']['checkin']['Y-m-d'] .
            " - " .
            $data['norm']['dates_from_search_form']['checkout']['Y-m-d'] .
            " - " .
            $data['values']['guests'];

          $data['destination'] = Link::createFromRoute(t('Book now'), 'entity.node.canonical', [
            'node' => $beeHotelUnit['node']->Id(),
            'v' => $data['v_param'],
          ]);

          $context = new Context(\Drupal::currentUser(),
                        \Drupal::entityTypeManager()->getStorage('commerce_store')->load($beeHotelUnit['store']->Id()));

          $purchasable_entity = $variation;
          $data['addtocart']['caller'] = __CLASS__ . "::" . __FUNCTION__;
          $this->beehotelunit->storeInSession($data);
          $resolved_price = $this->chainPriceResolver->resolve($purchasable_entity, 1, $context);
          $number = $resolved_price->getNumber();
          $currency_code = $resolved_price->getCurrencyCode();
          $commercePriceCalc = \Drupal::service('commerce_order.price_calculator');

          if (isset($commercePriceCalc)) {

            $price = $commercePriceCalc->calculate($variation, 1, $context);
            $calculatedprice = $price->getCalculatedPrice();
            $currency_formatter = \Drupal::service('commerce_price.currency_formatter');
            $formattedprice = $currency_formatter->format($calculatedprice->getNumber(), $calculatedprice->getCurrencyCode(), [
              'locale' => $beeHotelUnit['store']->get("langcode")->value,
              'minimum_fraction_digits' => 2,
              'maximum_fraction_digits' => 2,
              'currency_display' => 'none',
            ]);

            $items[] = [
              '#theme' => 'bee_hotel_s_unit',
              '#currency' => $calculatedprice->getCurrencyCode(),
              '#img' => render($beeHotelUnit['images']['main']['image']),
              '#nights' => $data['norm']['dates_from_search_form']['days'],
              '#price' => $formattedprice,
              '#title' => $beeHotelUnit['node']->getTitle(),
              '#store' => $beeHotelUnit['store']->get('name')->value,
              '#product_id' => $beeHotelUnit['pid'],
              '#variation_id' => (int) $purchasable_entity->id(),
              '#destination' => $data['destination'],
            ];

            // Optional field for marketing pourposes.
            if ($beeHotelUnit['node']->hasField('field_slogan')) {
              $items['#description'] = $beeHotelUnit['node']->get("field_slogan")->value;
            }
          }
          return $items;
        }
      }
    }
  }

}

==> bee_hotel-2.16.x-dev.tar.gz: bee_hotel/src/Form/UnitsSearch.php <==
<?php

namespace Drupal\bee_hotel\Form;

use Drupal\Core\Link;
use Drupal\bee_hotel\Util\BeeHotelUnit;
use Drupal\commerce\Context;
use Drupal\commerce_price\Resolver\ChainPriceResolverInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\NodeInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Search form for available beehotel units.
 */
class UnitsSearch extends FormBase {

  /**
   * The chain price resolver.
   *
   * @var \Drupal\commerce_price\Resolver\ChainPriceResolverInterface
   */
  protected $chainPriceResolver;

  /**
   * Constructs a new UnitsSeach object.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   User account.
   * @param \Drupal\commerce_price\Resolver\ChainPriceResolverInterface $chain_price_resolver
   *   Chain price resolver.
   */
  public function __construct(AccountInterface $account, ChainPriceResolverInterface $chain_price_resolver) {
    $this->account = $account;
    $this->chainPriceResolver = $chain_price_resolver;
    $this->beehotelunit = new BeeHotelUnit($data = []);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load required services to construct this class.
      $container->get('current_user'),
      $container->get('commerce_price.chain_price_resolver'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'beehotel_units_search';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, NodeInterface $node = NULL) {

    $config = $this->config('beehotel.settings');

    if ($config->get("beehotel.off_value")) {
      \Drupal::messenger()->addWarning($config->get("beehotel.off_text"));
      return;
    }

    // Get current user data.
    $uid = $this->account->id();

    // Clean booking related data in session.
    $session = \Drupal::request()->getSession();
    $session->set('beehotel_data', []);

    $today = new \DateTime();

    $tomorrow = clone($today);
    $tomorrow->modify('+1 day');

    $one_hour_later = clone($today);
    $one_hour_later->modify('+1 hour');

    $form['#prefix'] = "<div id='units-search-form-container'>";

    // Dates.
    $form['dates'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Check in > Check out'),
      '#default_value' => date("j M Y", strtotime("+1 day")) . " - " . date("j M Y", strtotime("+3 day")),
      '#required' => TRUE,
      '#weight' => -1000,
    ];

    // People (occupants).
    $max_occupancy = $this->beehotelunit->maxOccupancy($node = NULL);
    $options = [];
    for ($o = 1; $o <= $max_occupancy; $o++) {
      $options[$o] = $o . " " . t("guests");
    }

    $form['guests'] = [
      '#type' => 'select',
      '#title' => $this->t('Guests'),
      '#options' => $options,
      '#required' => TRUE,
    ];

    $form['submit'] = [
      '#type' => 'button',
      '#value' => t('Search'),
    ];

    $form['#suffix'] = "</div>";

    if ($form_state->getTriggeringElement()) {
      $items = $this->produceResult($form_state);
      $form['#suffix'] .= "<div class='label'>" . t("Results") . "</div><div class='result units'>" . render($items) . "</div>";
    }

    $form['#attached']['library'][] = 'bee_hotel/beehotel-litepicker';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $data['values'] = $form_state->getValues();
    $data = $this->beehotelunit->getAvailableUnits($data);
    // Basic date validation.
    if (empty($data['available_units'])) {
      $form_state->setErrorByName('checkout', $this->t('No availability, sorry...'));
      return;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->setRebuild(TRUE);
  }

  /**
   * Produce results.
   *
   * Produce results from submitted values.
   */
  private function produceResult($form_state) {
    $data = [];
    $data['values'] = $form_state->getValues();

    $data = $this->beehotelunit->getAvailableUnits($data);

    foreach ($data['available_units'] as $unit_id) {

      $beeHotelUnit = $this->beehotelunit->getUnitFromBid($unit_id);

      if (isset($beeHotelUnit)) {

        // Unit disabled.
        if ($beeHotelUnit['node']->get("status")->value != 1) {
          continue;
        }

        // Unit not accepting reservations.
        if ($beeHotelUnit['node']->get("field_accept_reservations")->value != 1) {
          continue;
        }

        $variation = $this->beehotelunit->GetCurrentVariation($beeHotelUnit, $data);

        if (isset($variation)) {

          $data['v_param'] = $data['norm']['dates_from_search_form']['checkin']['Y-m-d'] .
            " - " .
            $data['norm']['dates_from_search_form']['checkout']['Y-m-d'] .
            " - " .
            $data['values']['guests'];

          $data['destination']['title'] = Link::createFromRoute($beeHotelUnit['node']->getTitle(), 'entity.node.canonical', [
            'node' => $beeHotelUnit['node']->Id(),
            'v' => $data['v_param'],
          ]);

          $data['destination']['text'] = Link::createFromRoute(t('Book now'), 'entity.node.canonical', [
            'node' => $beeHotelUnit['node']->Id(),
            'v' => $data['v_param'],
          ]);

          $data['destination']['img'] = Link::createFromRoute($beeHotelUnit['image_large']['markup'], 'entity.node.canonical', [
            'node' => $beeHotelUnit['node']->Id(),
            'v' => $data['v_param'],
          ]);

          $context = new Context(\Drupal::currentUser(),
                        \Drupal::entityTypeManager()->getStorage('commerce_store')->load($beeHotelUnit['store']->Id()));

          $purchasable_entity = $variation;
          $data['addtocart']['caller'] = __CLASS__ . "::" . __FUNCTION__;
          $this->beehotelunit->storeInSession($data);
          $resolved_price = $this->chainPriceResolver->resolve($purchasable_entity, 1, $context);
          $number = $resolved_price->getNumber();
          $currency_code = $resolved_price->getCurrencyCode();
          $commercePriceCalc = \Drupal::service('commerce_order.price_calculator');

          if (isset($commercePriceCalc)) {

            $price = $commercePriceCalc->calculate($variation, 1, $context);
            $calculatedprice = $price->getCalculatedPrice();
            $currency_formatter = \Drupal::service('commerce_price.currency_formatter');
            $formattedprice = $currency_formatter->format($calculatedprice->getNumber(), $calculatedprice->getCurrencyCode(), [
              'locale' => $beeHotelUnit['store']->get("langcode")->value,
              'minimum_fraction_digits' => 2,
              'maximum_fraction_digits' => 2,
              'currency_display' => 'none',
            ]);

            $items[] = [
              '#theme' => 'bee_hotel_s_unit',
              '#currency' => $calculatedprice->getCurrencyCode(),
              '#img' => $data['destination']['img'],
              '#nights' => $data['norm']['dates_from_search_form']['days'],
              '#price' => $formattedprice,
              '#title' => $data['destination']['title'],
              '#store' => $beeHotelUnit['store']->get('name')->value,
              '#product_id' => $beeHotelUnit['pid'],
              '#variation_id' => (int) $purchasable_entity->id(),
              '#destination' => $data['destination']['text'],
            ];

            // Optional field for marketing pourposes.
            if ($beeHotelUnit['node']->hasField('field_slogan')) {
              $items['#description'] = $beeHotelUnit['node']->get("field_slogan")->value;
            }
          }
        }
      }
    }
    return $items;
  }

}
